#add-user-team .list-group-item:hover {
  background-color: rgba(0, 0, 0, 0.02);
}

.users-modal-overlay {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  display: flex;
  justify-content: center;
  align-items: flex-start;
  padding-top: 10vh;
  background-color: rgba(0, 0, 0, 0.35);
}

.users-modal {
  position: relative;
  display: flex;
  flex-direction: column;
  width: 50vw;
  height: auto;
  max-height: 80vh;
  background-color: white;
  border-radius: 10px;
  min-width: 420px;
  padding-bottom: 72px;
  overflow: hidden;
}

.users-modal .btn-close {
  position: absolute;
  top: 20px;
  right: 20px;
}

.users-modal-list {
  margin: 0;
  padding: 0;
  list-style: none;
  overflow: hidden;
  overflow-y: auto;
}

.users-modal-list li {
  padding: 8px 20px;
  border-bottom: 1px solid #eee;
}

.users-modal-list li:last-child {
  border-bottom: 0;
}

.users-modal-list li:hover {
  cursor: pointer;
  background-color: rgba(0, 0, 0, 0.03);
}

.users-modal-list .active,
.users-modal-list .active:hover {
  color: white;
  background-color: #285dc1;
}

.users-modal-header {
  padding: 20px;
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.1);
}

.users-modal-header h5 {
  padding-right: 40px;
}

.users-modal-base {
  position: absolute;
  right: 0;
  bottom: 0;
  left: 0;
  display: flex;
  justify-content: flex-end;
  align-items: center;
  padding: 0 20px;
  height: 72px;
  box-shadow: 0 -1px 5px rgba(0, 0, 0, 0.1);
}

.remove-user-text {
  display: none;
}

.btn-remove-user:hover .remove-user-text {
  display: inline;
}
