#add-user-team {
  position: relative;
}

#add-user-team.disabled {
  opacity: 0.3;
}

#add-user-team.disabled .lock {
  display: block;
}

#add-user-team.disabled .loader {
  display: none;
}

#add-user-team .lock {
  display: none;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: 9;
}

#add-user-team .lock .msg-lock {
  position: absolute;
  bottom: 26px;
  left: 0;
  right: 0;
  text-align: center;
  font-size: 20px;
  color: #333;
}

#add-user-team .title {
  margin-bottom: 5px;
}

#add-user-team .controls {
  padding: 0 10px;
  background-color: #ddd;
  border-radius: 2px;
  line-height: 50px;
  min-height: 50px;
  margin-bottom: 25px;
}

#add-user-team .box-users-teams {
  position: relative;
  background-color: #ddd;
  margin-bottom: 15px;
  border-radius: 2px;
  min-height: 74px;
  overflow: hidden;
}

#add-user-team .box-users-teams .loader {
  position: absolute;
  top: 50%;
  left: 50%;
  margin-left: -45px;
  margin-top: -8px;
}

/* #add-user-team .related-users {
  display: none;
  padding: 0;
  list-style: none;
  margin: 0;
  width: 100%;
  border-radius: 2px;
}

#add-user-team .related-users th {
  padding: 8px 10px;
  text-transform: uppercase;
  background-color: #ccc;
  font-size: 11px;
}

#add-user-team .related-users td {
  padding: 8px 10px;
  border-top: 1px solid #ccc;
}

#add-user-team .related-users tbody tr:hover {
  background-color: #d2d2d2;
}

#add-user-team .related-users li:first-child {
  border-top: none;
} */

#add-user-team .users,
#add-user-team .groups {
  width: 20%;
  display: inline-block;
}

#add-user-team .remove-usr {
  float: right;
}

#add-user-team .dropdown-menu {
  max-height: 280px;
  overflow-y: auto;
}

#add-user-team .add-btn {
  float: right;
  margin-top: 10px;
}

.lbl-user {
  margin-bottom: 5px;
}
