{% load i18n static %}

<section id="add-user-role" {% if not has_id %}class="disabled"{% endif %}>
  <label>{% trans 'Manage Users:' %}</label>

  <div class="form-group mb-3">
    <select class="users form-select">
      <option value="" disabled selected>{% trans 'Select user...' %}</option>
      {% for user in users %}
        <option value="{{ user.id }}">{{ user.name }}</option>
      {% endfor %}
    </select>
  </div>
  <div class="form-group mb-3">
    <select class="roles form-select">
      <option value="" disabled selected>{% trans 'Select role...' %}</option>
      {% for role in roles %}
        <option value="{{ role.id }}">{{ role.name }}</option>
      {% endfor %}
    </select>
  </div>

  <div class="form-group mb-3 text-end">
    <a href="#" class="btn btn-primary btn-sm add-btn">{% trans 'Add' %}</a>
  </div>

  <div class="form-group mb-3">
  <div class="box-table box-users">
    <div class="users-loading">
      <i class="fas fa-lg fa-cog fa-pulse"></i>
    </div>
    <table class="table related-users">
      <thead>
        <tr>
          <th width="45%">{% trans 'user' %}</th>
          <th width="45%">{% trans 'role' %}</th>
          <th>&nbsp;</th>
        </tr>
      </thead>
      <tbody></tbody>
    </table>
  </div>
  </div>

  <div class="lock">
    <span class="msg-lock">{% trans 'Create project to manage users' %}</span>
  </div>
</section>
