{% extends "vault/base.html" %}

{% load i18n static %}

{% block title %}Object Storage &rsaquo; {% trans "Migration Status" %}{% endblock %}

{% block some_top_info %}{% trans "Cloud Migration" %}{% endblock %}

{% block content_title %}{% trans "Migration Status" %}{% endblock %}

{% block content_breadcrumb %}
<span>{% trans 'Cloud Migration' %}</span>
<span>{% trans "Migration Status" %}</span>
{% endblock %}

{% block content %}
<div id="migration-status-app"></div>
{% endblock %}

{% block js_bottom %}
<script>
const PROJECTS = JSON.parse('{{ projects|escapejs }}');
const MIGRATION_DATA = JSON.parse('{{ migration_data|escapejs }}');
const PROJECT_STATUS_URL = "{% url 'swift_cloud_project_status' %}";
const MIGRATE_URL = "{% url 'swift_cloud_migrate' %}";
</script>
<script src="{% static 'vault/js/swift_cloud/status.js' %}"></script>
{% endblock %}
